@@ -667,7 +667,8 @@ onMAinfo <- function(){
     tc <- tklabel(info.window, image="resolution.image")
     tkgrid(tc)
     catlginfo <- ttklabel(info.window,text="Designs in 32 runs are available for up to 31 factors (resolution III).")
-    catlginfo2 <- ttklabel(info.window,text="Designs in 64 runs are available for up to 32 factors (resolution IV).")
+    catlginfo2 <- ttklabel(info.window,text="Designs in 64 runs are available for up to 32 factors (resolution IV) and 33 to 63 factors (resolution III).")
+    catlginfo2 <- ttklabel(info.window,text="Designs in 128 runs are available for up to 64 factors (resolution IV) and 65 to 127 factors (resolution III).")
     tkgrid(catlginfo)
     tkgrid(catlginfo2)
 
@@ -697,7 +698,8 @@ onMaxC2info <- function(){
     if (tclvalue(resVar)=="IV") tkgrid(ttklabel(info.window,text="NOTE: yellow: resolution IV, green: resolution V+"))
     tc <- tklabel(info.window, image="MaxC2.image")
     tkgrid(tc)
-    catlginfo <- ttklabel(info.window,text=gettextRcmdr("Cell entries for resolution III and IV designs:"))
+    if (tclvalue(resVar)=="III") catlginfo <- ttklabel(info.window,text=gettextRcmdr("Cell entries for resolution III and IV designs:"))
+    else catlginfo <- ttklabel(info.window,text=gettextRcmdr("Cell entries for resolution IV designs:"))
     catlginfo2 <- ttklabel(info.window,text=gettextRcmdr("maximum number of clear 2fis and maximum number of factors with all 2fis clear."))
     tkgrid(catlginfo)
     tkgrid(catlginfo2)
